# Developer Tips

## AI-assisted development

This documentation is mirrored in the [docs folder of Tinker Cookbook](https://github.com/thinking-machines-lab/tinker-cookbook/tree/main/docs). The root of Tinker Cookbook also contains an `AGENTS.md` / `CLAUDE.md` file with a guide to the code and documentation. We recommend making a git clone of the cookbook and pointing your coding agent at the repository root.
